<?php

/**
 * @file
 * Functions related to the additional user_verify roles.
 */

/**
 * Provide a list with all module specific role names.
 *
 * @return array
 *   An array containing all full role names as values,
 *   keyed by their internal short names.
 */
function _user_verify_roles_list() {
  static $roles;
  if (!isset($roles)) {
    $roles = array();
    foreach (array(
      'quarantined',
      'pending',
      'passed',
      'failed',
      'applied',
      'granted',
    ) as $stub) {
      $roles[$stub] = "user_verify_${stub}";
    }
  }
  return $roles;
}

/**
 * Installs the module specific roles.
 *
 * @return bool
 *   TRUE on success, FALSE otherwise.
 */
function _user_verify_roles_install() {

  // Will be falsed on errors.
  $ret = TRUE;

  foreach (_user_verify_roles_list() as $rolename) {
    if (!user_role_load_by_name($rolename)) {
      $role = new stdClass();
      $role->name = $rolename;
      $ret = $ret && user_role_save($role) != FALSE;
    }
  }

  return $ret;
}

/**
 * Uninstalls the module specific roles.
 */
function _user_verify_roles_uninstall() {

  foreach (_user_verify_roles_list() as $rolename) {
    user_role_delete($rolename);
  }

  // No result possible as user_role_delete() lacks a return value.
}

/**
 * Checks whether all module specific roles exist.
 *
 * @return bool
 */
function _user_verify_roles_verify() {

  // Will be falsed on errors.
  $ret = TRUE;
  foreach (_user_verify_roles_list() as $rolename) {
    $ret = $ret && user_role_load_by_name($rolename) != FALSE;
  }

  return $ret;
}
