<?php

/**
 * @file
 * Hooks provided by the user verification module.
 *
 * This module does not contain functional code, but examples to help you
 * extending this module.
 */

/**
 * @addtogroup hooks
 * @{
 */

/**
 * A user has been put into quarantine phase.
 *
 * @param object $account
 *   The affected user account object.
 * @param int $time_init
 *   Informational updated UNIX timestamp of the quarantine's end.
 */
function hook_user_verify_quarantined(&$account, $endtime) {
  // Do something with $account's data, e.g. inform the user about our secret
  // actions. (Best practice ever!!1!)
  drupal_set_message(
    t('Hey !name, your quarantine has been set to end at !time because we do find you suspicious!', array(
      '!name' => $account->name,
      '!time' => format_date($endtime, 'short'),
    ))
  );
}

/**
 * A user has entered the verification phase.
 *
 * @param object $account
 *   The affected user account object.
 */
function hook_user_verify_inited($account) {
  // Do something with $account's data, e.g. add its uid to an
  // observation list.
  mymodule_add_user_id($account->uid);
}

/**
 * A user has failed his challenge or has been denied computed trust.
 *
 * @param object $account
 *   The affected user account object.
 */
function hook_user_verify_failed($account) {
  // Do something with $account's data, e.g. add its uid to a
  // "review suspicious" list.
  mymodule_add_user_id($account->uid);
}

/**
 * A user has passed his challenge or has acquired any computed trust.
 *
 * @param object $account
 *   The affected user account object.
 */
function hook_user_verify_passed($account) {
  // Do something with $account's data, e.g. add its uid to a
  // "verified users" list.
  mymodule_add_user_id($account->uid);
}

/**
 * A user has been granted trust.
 *
 * @param object $account
 *   The affected user account object.
 */
function hook_user_verify_granted($account) {
  // Do something with $account's data, e.g. add its uid to a
  // "trusted users" list.
  mymodule_add_user_id($account->uid);
}

/**
 * User trust has been revoked.
 *
 * @param object $account
 *   The affected user account object.
 */
function hook_user_verify_revoked($account) {
  // Do something with $account's data, e.g. add its uid to a
  // "revoked users" list.
  mymodule_add_user_id($account->uid);
}

/**
 * Modify the roles to exclude from cron cleanup tasks.
 *
 * @param array &$exclude_roles
 *   Optional roles a user needs to bypass cleanup processes.
 *   Module default is array('granted').
 * @param string $op
 *   Informational: The cleanup task about to be performed.
 *   Currently one of 'pending' and 'failed'.
 */
function hook_user_verify_cleanup_alter(&$exclude_roles, $op) {
  // Add or remove roles you want to protect accounts from being
  // automatically removed.
  if ($op == 'pending') {
    $exclude_roles = array_merge($exclude_roles, array('another_trusted_role', 'even_another_one'));
  }
}

/**
 * @} End of "addtogroup hooks".
 */
