<?php

/**
 * @file
 * API integration with the variable module.
 */


/**
 * Implements hook_variable_group_info().
 */
function user_verify_variable_group_info() {
  return array(
    'user_verification' => array(
      'title' => t('User verification'),
      'description' => t('Variables used by the user verification module.'),
    ),
  );
}

/**
 * Implements hook_variable_info().
 */
function user_verify_variable_info($options) {

  return array(

    // Configurable

    'user_verify_enable_quarantine' => array(
      'type' => 'boolean',
      'title' => t('Enable quarantine', array(), $options),
      'description' => t('Whether or not to enable quarantine.', array(), $options),
      'default' => TRUE,
      'group' => 'user_verification',
    ),
    'user_verify_quarantine_duration_min' => array(
      'type' => 'number',
      'title' => t('Quarantine minimum'),
      'description' => t('Minimal duration of the quarantine period. Used for randomization.', array(), $options),
      'default' => 10 * 60, // 10 minutes in seconds.
      'group' => 'user_verification',
    ),
    'user_verify_quarantine_duration_max' => array(
      'type' => 'number',
      'title' => t('Quarantine maximum'),
      'description' => t('Maximal duration of the quarantine period. Used for randomization.', array(), $options),
      'default' => 10 * 24 * 60 * 60, // 10 days in seconds.
      'group' => 'user_verification',
    ),
    'user_verify_application_stub' => array(
      'type' => 'string',
      'title' => t('Application path stub', array(), $options),
      'description' => t('Path stub for the user-individual application form path. The menu router is built dynamically from this input.'),
      'default' => '',
      'group' => 'user_verification',
    ),
    'user_verify_challenge_stub' => array(
      'type' => 'string',
      'title' => t('Challenge path stub', array(), $options),
      'description' => t('Path stub for the user-individual challenge path. The menu router is built dynamically from this input.'),
      'default' => '',
      'group' => 'user_verification',
    ),
    'user_verify_pending_timeout' => array(
      'type' => 'number',
      'title' => t('Verification time', array(), $options),
      'description' => t("Duration of the verification period. Setting up a sensible value far from zero seconds is recommended, yet not required (for configurability's sake).", array(), $options),
      // A random number of days in seconds to limit the
      // impact of a site admin being in a hurry.
      'default' => rand(60 * 60 * 24 * 7, 60 * 60 * 24 * 21),
      'group' => 'user_verification',
    ),
    'user_verify_pending_delete' => array(
      'type' => 'boolean',
      'title' => t('Cleanup unverified accounts', array(), $options),
      'description' => t('Whether or not to delete accounts who did not even try to verify.', array(), $options),
      'default' => FALSE,
      'group' => 'user_verification',
    ),
    'user_verify_failed_timeout' => array(
      'type' => 'number',
      'title' => t('Grace period', array(), $options),
      'description' => t('How long to wait before "cleanup" action is triggered for an unsuccessfully verified account.', array(), $options),
      // A random number of days in seconds to limit the
      // impact of a site admin being in a hurry.
      'default' => rand(60 * 60 * 24 * 5, 60 * 60 * 24 * 15),
      'group' => 'user_verification',
    ),
    'user_verify_failed_delete' => array(
      'type' => 'boolean',
      'title' => t('Cleanup failed accounts', array(), $options),
      'description' => t('Whether or not to delete accounts who did not even try to verify.', array(), $options),
      'default' => FALSE,
      'group' => 'user_verification',
    ),
    'user_verify_max_errors' => array(
      'type' => 'number',
      'title' => t('User verification error limit'),
      'description' => t('The maximum number of incorrect verification attempts for a pending user.', array(), $options),
      'default' => rand(2,4),
      'group' => 'user_verification',
    ),
    'user_verify_watchdog' => array(
      'type' => 'boolean',
      'title' => t('Log events', array(), $options),
      'description' => t('Whether or not to add to the Drupal "syslog" (watchdog).', array(), $options),
      'default' => TRUE,
      'group' => 'user_verification',
    ),

    // Internal
    'user_verify_application_menu_item' => array(
      'type' => 'array',
      'title' => t('Application form menu item data', array(), $options),
      'description' => t('Prepared menu item data for hook_menu(); needs to be generated dynamically to allow for an arbitrary wildcard position.'),
      'default' => array(),
      'group' => 'user_verification',
    ),
    'user_verify_challenge_menu_item' => array(
      'type' => 'array',
      'title' => t('Challenge menu item data', array(), $options),
      'description' => t('Prepared menu item data for hook_menu(); needs to be generated dynamically to allow for an arbitrary wildcard position.'),
      'default' => array(),
      'group' => 'user_verification',
    ),
    // Internal: configuration tracker.
    //
    // This variable should not render TRUE" unless any
    // "required-individual-manual" value has been configured, submitted
    // and validated. Keep in mind that this module needs manual interaction
    // (beyond "enable"!) if you want it to work properly!
    // While FALSE, additional admin warnings in the backend are triggered.
    'user_verify_configured' => array(
      'type' => 'boolean',
      'title' => t('Setup complete'),
      'description' => t('User verification must be explicitely configured and will not work without that. This value should only be changed to true by saving the settings form..'),
      'default' => FALSE,
      'group' => 'user_verification',
    ),
  );
}
